# RBM Analyses Package

Data analysis with the reduced Bayesian model (RBM).

### agent_rbm

The package contains a Python implementation of the RBM. The model can be used for simulations and for parameter
estimation. Examples coming soon. 

### circular_regression

It also contains code for custom regression models (currently circular) that can be combined with the RBM.
See "examples" folder for a minimal regression example.

## Questions?

For questions, please get in touch with me: [rasmusb@zedat.fu-berlin.de](rasmusb@zedat.fu-berlin.de)

## Built With

* [Python](https://www.python.org)
* Requires the [allinpy package](https://github.com/rasmusbruckner/allinpy)

## Author

* **Rasmus Bruckner** - [GitHub](https://github.com/rasmusbruckner) - [Freie Universität Berlin](https://www.ewi-psy.fu-berlin.de/en/einrichtungen/arbeitsbereiche/neural_dyn_of_vis_cog/learning-lab/team/bruckner/index.html)

## Acknowledgments

[Matt Nassar](https://sites.brown.edu/mattlab/) and
[Hashim Satti](https://www.ewi-psy.fu-berlin.de/en/psychologie/arbeitsbereiche/neural_dyn_of_vis_cog/learning-lab/team/satti/index.html)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
